==> cbol-1.5.tgz: cbol-1.5/ref.php <==
<?php
function ref($bibletxt,$engs,$ochap,$db_conn,$VER)
{
    require("config.php");
    //require("dbconfig.php");
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"#"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
        /****** oO]sX|X{u|vҥHnBz@U *****/
        $ttmpt=substr($tmp,$pt);
        $pt1=strpos($ttmpt,"|");
	$pt1=$pt1+$pt;
        if ($pt1==0)
        {
           echo "error in bible reference parsing $tmp <br>";
           return;
        }
 	/**** Add process to strong num ***/
	$refstr=substr($tmp,$pt+1,$pt1-$pt-1);
	$refstr=ereg_replace("with","",$refstr); //onwith
	/**** process refstr ****/
        //echo "pt1=$pt1 pt=$pt" ;
	$wtok=split("[|;]",$refstr); //ޥθ
	$ii=count($wtok);
	$book=$engs;
	$chap=0;
	$sec=0;
	for ($i=0;$i<$ii;$i++)
	{
		$wtok[$i]=trim($wtok[$i]);
		//echo $wtok[$i];
		$btok=array("","","");
		$cnt=0;
		$stok=strtok($wtok[$i]," :;|");
		while (!($stok === FALSE))
		{
		    if (strlen($stok)) //ŦrAѨMD
                    {
			if ($cnt>0)
                        {
                           $testchar=substr($btok[$cnt-1],strlen($btok[$cnt-1])-1);
                                //ˬdڨSu
                           if ($testchar===',' || $testchar==='-')
                           {
                                $btok[$cnt-1]=$btok[$cnt-1].$stok;
                                 $stok=strtok(" :\n;|");
                                 continue;
                           }
                        }
		    	$btok[$cnt]=$stok;
		    	$cnt=$cnt+1;
                    }
		    $stok=strtok(" :\n;|");

		}
		switch ($cnt)
		{
		 case 4: //# 2Ch 14:1-16:14
			$book=trim($btok[0]);
                        $chap=(int)$btok[1];
			$ctmp=split("-",$btok[2]); //} 1-16
			$sec=$ctmp[0];
			$chap2=$ctmp[1];
                        $sec2=$btok[3];
			break;
		 case 3:  //#mt 1:2 Ӥ@G`
			//P_@U OO # 14:1-16:14
			if (strstr($btok[1],"-"))
			{
                          $chap=(int)$btok[0];
			  $ctmp=split("-",$btok[1]); //} 1-16
			  $sec=$ctmp[0];
			  $chap2=$ctmp[1];
                          $sec2=$btok[2];
			  $cnt=4; //Pe@تp
			}
			else
			{
			   $book=trim($btok[0]);
                           $chap=(int)$btok[1];
                           $sec=$btok[2];
			}
			break;
		 case 2: //#1:2 @G`  mt 1 @㳹
			$btok[0]=trim($btok[0]);
			if (!ctype_digit($btok[0])) //ܬO mt 1
		        {
			   $book=$btok[0];
                           $chap=(int)$btok[1];
			}
			else
			{
                        	$chap=(int)$btok[0];
                        	$sec=$btok[1];
			}
			break;
		 case 1: //#1 Ĥ@`  Ĥ@
			if ($ochap==0) $chap=$btok[0];
			else 
			{
                        	$chap=$ochap;
                        	$sec=$btok[0];
			}
			break;
		/*******
		default: 
			echo "Error in parser btok, Cnt= $cnt";
		*******/
		}
	      if (Ord($book)<128)
	      {
	        $QUERY="select chineses,engs from main where sengs = '$book' or engs='$book'";
 		/******** }ldƮw ********/
 		$resultr=db_exec($db_conn,$QUERY);
 		if (!$resultr){
                        echo("Ʈwd߿~AO $QUERY !");
                        exit;
 		}
 		if (!$resultr){
                        echo("Ʈwd߿~AO $QUERY !");
                        return "";
 		}
		$numrow=db_NumRows($resultr);
		if ($numrow!=1)
		{
                        echo( "@@dX $numrow AޥθƦDI$QUERY");
                        return "";
		}
		 $ARAW=db_fetch_row($resultr,0); //Ū@O
		$ARAW[0]=trim($ARAW[0]);
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\" target=\"ref\">$wtok[$i]</a> ";
		 elseif ($cnt>4)
    		 $bibletxt=$bibletxt.$wtok[$i];
		 else
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec\" target=\"ref\">$wtok[$i]</a> ";
	     } //if Ord ˬdO_^
	     else //աI
		{
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\" target=\"ref\">$wtok[$i]</a> ";
		 else
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec\" target=\"ref\">$wtok[$i]</a> ";
		}
		//echo "book=$book chap=$chap sec=$sec <br>\n"; 
	}
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
	//echo "tmp=$tmp";
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}
/*********** Topic Ref **************/
function tref($bibletxt,$db_conn,$N)
{
    $STP='st.php';
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"[!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
	$tmp=substr($tmp,$pt+2);
        $pt1=strpos($tmp,"!]");
        if ($pt1==0)
        {
           echo "error in topic reference parsing $tmp <br>";
           return;
        }
	$refstr=substr($tmp,0,$pt1);
        if (ord($refstr)>127) $N=$N%2+2; //D
        else $N=$N%2;
    	$bibletxt=$bibletxt." <a href=\"{$STP}?N=$N&keyword={$refstr}\" target=\"ref\">{$refstr}</a> ";
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+2);
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}
/*********** SN Ref **************/
function snref($bibletxt,$db_conn)
{
    $STP='s.php';
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"<WH"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
	$tmp=substr($tmp,$pt+3);
        $pt1=strpos($tmp,">");
        if ($pt1==0)
        {
           echo "error in topic reference parsing $tmp <br>";
           return;
        }
	$refstr=substr($tmp,0,$pt1);
    	$bibletxt=$bibletxt." <a href=\"{$STP}?N=1&k={$refstr}\" target=\"nw\">{$refstr}</a> ";
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
    }
    $bibletxt=$bibletxt.$tmp;
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"<WG"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
	$tmp=substr($tmp,$pt+3);
        $pt1=strpos($tmp,">");
        if ($pt1==0)
        {
           echo "error in topic reference parsing $tmp <br>";
           return;
        }
	$refstr=substr($tmp,0,$pt1);
    	$bibletxt=$bibletxt." <a href=\"{$STP}?N=0&k={$refstr}\" target=\"nw\">{$refstr}</a> ";
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}

==> cbol-3.0.tgz: cbol-3.0/ref.php <==
<?php
function ref($bibletxt,$engs,$ochap,$db_conn,$VER)
{
    require("config.php");
    //require("dbconfig.php");
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"#"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
        /****** oO]sX|X{u|vҥHnBz@U *****/
        $ttmpt=substr($tmp,$pt);
        $pt1=strpos($ttmpt,"|");
	$pt1=$pt1+$pt;
        if ($pt1==0)
        {
           echo "error in bible reference parsing $tmp <br>";
           return;
        }
 	/**** Add process to strong num ***/
	$refstr=substr($tmp,$pt+1,$pt1-$pt-1);
	$refstr=ereg_replace("with","",$refstr); //onwith
	/**** process refstr ****/
        //echo "pt1=$pt1 pt=$pt" ;
	$wtok=split("[|;]",$refstr); //ޥθ
	$ii=count($wtok);
	$book=$engs;
	$chap=0;
	$sec=0;
	for ($i=0;$i<$ii;$i++)
	{
		$wtok[$i]=trim($wtok[$i]);
		//echo $wtok[$i];
		$btok=array("","","");
		$cnt=0;
		$stok=strtok($wtok[$i]," :;|");
		while (!($stok === FALSE))
		{
		    if (strlen($stok)) //ŦrAѨMD
                    {
			if ($cnt>0)
                        {
                           $testchar=substr($btok[$cnt-1],strlen($btok[$cnt-1])-1);
                                //ˬdڨSu
                           if ($testchar===',' || $testchar==='-')
                           {
                                $btok[$cnt-1]=$btok[$cnt-1].$stok;
                                 $stok=strtok(" :\n;|");
                                 continue;
                           }
                        }
		    	$btok[$cnt]=$stok;
		    	$cnt=$cnt+1;
                    }
		    $stok=strtok(" :\n;|");

		}
		switch ($cnt)
		{
		 case 4: //# 2Ch 14:1-16:14
			$book=trim($btok[0]);
                        $chap=(int)$btok[1];
			$ctmp=split("-",$btok[2]); //} 1-16
			$sec=$ctmp[0];
			$chap2=$ctmp[1];
                        $sec2=$btok[3];
			break;
		 case 3:  //#mt 1:2 Ӥ@G`
			//P_@U OO # 14:1-16:14
			if (strstr($btok[1],"-"))
			{
                          $chap=(int)$btok[0];
			  $ctmp=split("-",$btok[1]); //} 1-16
			  $sec=$ctmp[0];
			  $chap2=$ctmp[1];
                          $sec2=$btok[2];
			  $cnt=4; //Pe@تp
			}
			else
			{
			   $book=trim($btok[0]);
                           $chap=(int)$btok[1];
                           $sec=$btok[2];
			}
			break;
		 case 2: //#1:2 @G`  mt 1 @㳹
			$btok[0]=trim($btok[0]);
			if (!ctype_digit($btok[0])) //ܬO mt 1
		        {
			   $book=$btok[0];
                           $chap=(int)$btok[1];
			}
			else
			{
                        	$chap=(int)$btok[0];
                        	$sec=$btok[1];
			}
			break;
		 case 1: //#1 Ĥ@`  Ĥ@Τ@OĤ@nF
			$chap=$btok[0];
			$sec=0;
			/*********************************
			if ($ochap==0) $chap=$btok[0];
			else 
			{
                        	$chap=$ochap;
                        	$sec=$btok[0];
			}
			*************************/
			break;
		/*******
		default: 
			echo "Error in parser btok, Cnt= $cnt";
		*******/
		}
	      if (Ord($book)<128)
	      {
	        $QUERY="select chineses,engs from main where sengs = '$book' or engs='$book'";
 		/******** }ldƮw ********/
 		$resultr=db_exec($db_conn,$QUERY);
 		if (!$resultr){
                        echo("Ʈwd߿~AO $QUERY !");
                        exit;
 		}
 		if (!$resultr){
                        echo("Ʈwd߿~AO $QUERY !");
                        return "";
 		}
		$numrow=db_NumRows($resultr);
		if ($numrow!=1)
		{
                        echo( " $wtok[$i] @@dX $numrow AޥθƦDI$QUERY");
                        return "";
		}
		 $ARAW=db_fetch_row($resultr,0); //Ū@O
		$ARAW[0]=urlencode(trim($ARAW[0]));
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\" target=\"ref\">$wtok[$i]</a> ";
		 elseif ($cnt>4)
    		 $bibletxt=$bibletxt.$wtok[$i];
		 else
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$ARAW[0]&chap=$chap&sec=$sec\" target=\"ref\">$wtok[$i]</a> ";
	     } //if Ord ˬdO_^
	     else //աI
		{
		 if ($cnt==4)
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec&chap2=$chap2&sec2=$sec2\" target=\"ref\">$wtok[$i]</a> ";
		 else
    		 $bibletxt=$bibletxt." <a href=\"{$READP}?VERSION=$VER&TABFLAG=1&chineses=$book&chap=$chap&sec=$sec\" target=\"ref\">$wtok[$i]</a> ";
		}
		//echo "book=$book chap=$chap sec=$sec <br>\n"; 
	}
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
	//echo "tmp=$tmp";
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}
/*********** Topic Ref **************/
function tref($bibletxt,$db_conn,$N)
{
    $STP='st.php';
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"[!"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
	$tmp=substr($tmp,$pt+2);
        $pt1=strpos($tmp,"!]");
        if ($pt1==0)
        {
           echo "error in topic reference parsing $tmp <br>";
           return;
        }
	$refstr=substr($tmp,0,$pt1);
        if (ord($refstr)>127) $N=$N%2+2; //D
        else $N=$N%2;
    	$bibletxt=$bibletxt." <a href=\"{$STP}?N=$N&keyword={$refstr}\" target=\"ref\">{$refstr}</a> ";
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+2);
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}
/*********** SN Ref **************/
function snref($bibletxt,$db_conn)
{
    $STP='s.php';
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"<WH"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
	$tmp=substr($tmp,$pt+3);
        $pt1=strpos($tmp,">");
        if ($pt1==0)
        {
           echo "error in topic reference parsing $tmp <br>";
           return;
        }
	$refstr=substr($tmp,0,$pt1);
    	$bibletxt=$bibletxt." <a href=\"{$STP}?N=1&k={$refstr}\" target=\"nw\">{$refstr}</a> ";
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
    }
    $bibletxt=$bibletxt.$tmp;
    $tmp=$bibletxt;
    $bibletxt="";
    while (!(($pt=strpos($tmp,"<WG"))===false))
    {
        $ok1=substr($tmp,0,$pt);
	//$ok=htmlspecialchars($ok1);
	$ok=$ok1;
        $bibletxt=$bibletxt.$ok;
	$tmp=substr($tmp,$pt+3);
        $pt1=strpos($tmp,">");
        if ($pt1==0)
        {
           echo "error in topic reference parsing $tmp <br>";
           return;
        }
	$refstr=substr($tmp,0,$pt1);
    	$bibletxt=$bibletxt." <a href=\"{$STP}?N=0&k={$refstr}\" target=\"nw\">{$refstr}</a> ";
	/***** Next String ****/
        $tmp=substr($tmp,$pt1+1);
    }
    $bibletxt=$bibletxt.$tmp;
    return $bibletxt;
}
